@@ -1,4 +1,5 @@
 /* Gestures
+ * #Keywords: GtkGesture
  *
  * Perform gestures on touchscreens and other input devices. This
  * demo reacts to long presses and swipes from all devices, plus
@@ -207,7 +208,7 @@ do_gestures (GtkWidget *do_widget)
     }
 
   if (!gtk_widget_get_visible (window))
-    gtk_widget_show (window);
+    gtk_widget_set_visible (window, TRUE);
   else
     gtk_window_destroy (GTK_WINDOW (window));
 
