@@ -40,23 +40,12 @@
 #include <imm.h>
 
 /* Whether GDK initialized COM */
-static gboolean co_initialized = FALSE;
-
-/* Whether GDK initialized OLE */
-static gboolean ole_initialized = FALSE;
-
-void
-_gdk_win32_surfaceing_init (void)
-{
-  _gdk_win32_clipdrop_init ();
-
-  gdk_dmanipulation_initialize ();
-}
-
 gboolean
 gdk_win32_ensure_com (void)
 {
-  if (!co_initialized)
+  static gsize co_initialized = 0;
+
+  if (g_once_init_enter (&co_initialized))
     {
       /* UI thread should only use STA model. See
        * -> https://devblogs.microsoft.com/oldnewthing/20080424-00/?p=22603
@@ -64,11 +53,12 @@ gdk_win32_ensure_com (void)
        */
       const DWORD flags = COINIT_APARTMENTTHREADED |
                           COINIT_DISABLE_OLE1DDE;
+      gboolean init_result = FALSE;
       HRESULT hr;
 
       hr = CoInitializeEx (NULL, flags);
       if (SUCCEEDED (hr))
-        co_initialized = TRUE;
+        init_result = TRUE;
       else switch (hr)
         {
         case RPC_E_CHANGED_MODE:
@@ -79,19 +69,26 @@ gdk_win32_ensure_com (void)
           HR_LOG (hr);
         break;
         }
+
+      g_once_init_leave (&co_initialized, init_result);
     }
 
   return co_initialized;
 }
 
+/* Whether GDK initialized OLE */
 gboolean
 gdk_win32_ensure_ole (void)
 {
-  if (!ole_initialized)
+  static gsize ole_initialized = 0;
+
+  if (g_once_init_enter (&ole_initialized))
     {
+      gboolean init_result = FALSE;
       HRESULT hr = OleInitialize (NULL);
+
       if (SUCCEEDED (hr))
-        ole_initialized = TRUE;
+        init_result = TRUE;
       else switch (hr)
         {
         case RPC_E_CHANGED_MODE:
@@ -102,6 +99,8 @@ gdk_win32_ensure_ole (void)
           HR_LOG (hr);
         break;
         }
+
+       g_once_init_leave (&ole_initialized, init_result);
     }
 
   return ole_initialized;
@@ -243,9 +242,6 @@ _gdk_win32_surface_exstyle_to_string (LONG style)
   BIT (ACCEPTFILES);
   BIT (APPWINDOW);
   BIT (CLIENTEDGE);
-#ifndef WS_EX_COMPOSITED
-#  define WS_EX_COMPOSITED 0x02000000L
-#endif
   BIT (COMPOSITED);
   BIT (CONTEXTHELP);
   BIT (CONTROLPARENT);
