@@ -36,7 +36,7 @@ static VkResult
 gdk_win32_vulkan_context_create_surface (GdkVulkanContext *context,
                                          VkSurfaceKHR     *surface)
 {
-  GdkSurface *window = gdk_draw_context_get_surface (GDK_DRAW_CONTEXT (context));
+  GdkSurface *gdk_surface = gdk_draw_context_get_surface (GDK_DRAW_CONTEXT (context));
   GdkDisplay *display = gdk_draw_context_get_display (GDK_DRAW_CONTEXT (context));
   VkWin32SurfaceCreateInfoKHR info;
   VkResult result;
@@ -45,14 +45,7 @@ gdk_win32_vulkan_context_create_surface (GdkVulkanContext *context,
   info.pNext = NULL;
   info.flags = 0;
   info.hinstance = this_module ();
-  info.hwnd = GDK_SURFACE_HWND (window);
-
-  /* This is necessary so that Vulkan sees the Window.
-   * Usually, vkCreateWin32SurfaceKHR() will not cause a problem to happen as
-   * it just creates resources, but further calls with the resulting surface
-   * do cause issues.
-   */
-  gdk_display_sync (display);
+  info.hwnd = GDK_SURFACE_HWND (gdk_surface);
 
   result = GDK_VK_CHECK (vkCreateWin32SurfaceKHR,
                          gdk_vulkan_context_get_instance (context),
@@ -64,13 +57,15 @@ gdk_win32_vulkan_context_create_surface (GdkVulkanContext *context,
 }
 
 static void
-gdk_win32_vulkan_context_begin_frame (GdkDrawContext *draw_context,
-                                      GdkMemoryDepth  depth,
-                                      cairo_region_t *update_area)
+gdk_win32_vulkan_context_begin_frame (GdkDrawContext  *draw_context,
+                                      GdkMemoryDepth   depth,
+                                      cairo_region_t  *update_area,
+                                      GdkColorState  **out_color_state,
+                                      GdkMemoryDepth  *out_depth)
 {
   gdk_win32_surface_handle_queued_move_resize (draw_context);
 
-  GDK_DRAW_CONTEXT_CLASS (gdk_win32_vulkan_context_parent_class)->begin_frame (draw_context, depth, update_area);
+  GDK_DRAW_CONTEXT_CLASS (gdk_win32_vulkan_context_parent_class)->begin_frame (draw_context, depth, update_area, out_color_state, out_depth);
 }
 
 static void
